@@ -9,10 +9,8 @@ import audeer
 import audformat
 
 from audinterface.core import utils
-from audinterface.core.typing import (
-    Timestamp,
-    Timestamps,
-)
+from audinterface.core.typing import Timestamp
+from audinterface.core.typing import Timestamps
 
 
 def create_process_func(
@@ -20,7 +18,6 @@ def create_process_func(
         invert: bool,
 ) -> typing.Callable[..., pd.MultiIndex]:
     r"""Create processing function."""
-
     if process_func is None:
         def process_func(signal, sr, **kwargs):
             return utils.signal_index()
@@ -374,12 +371,22 @@ class Segment:
             index: pd.Index,
             *,
             root: str = None,
+            cache_root: str = None,
     ) -> pd.Index:
         r"""Segment files or segments from an index.
 
+        If ``cache_root`` is not ``None``,
+        a hash value is created from the index
+        using :func:`audformat.utils.hash` and
+        the result is stored as
+        ``<cache_root>/<hash>.pkl``.
+        When called again with the same index,
+        results will be read from the cached file.
+
         Args:
             index: index conform to audformat_
             root: root folder to expand relative file paths
+            cache_root: cache folder (see description)
 
         Returns:
             Segmented index conform to audformat_
@@ -397,13 +404,23 @@ class Segment:
         if index.empty:
             return index
 
-        return self.process_files(
-            index.get_level_values('file'),
-            starts=index.get_level_values('start'),
-            ends=index.get_level_values('end'),
+        y = self.process.process_index(
+            index,
+            preserve_index=False,
             root=root,
+            cache_root=cache_root,
         )
 
+        files = []
+        starts = []
+        ends = []
+        for (file, start, _), index in y.items():
+            files.extend([file] * len(index))
+            starts.extend(index.levels[0] + start)
+            ends.extend(index.levels[1] + start)
+
+        return audformat.segmented_index(files, starts, ends)
+
     def process_signal(
             self,
             signal: np.ndarray,
