@@ -7,19 +7,16 @@ import pandas as pd
 
 import audeer
 import audformat
+import audiofile as af
 import audmath
 import audresample
-import audiofile as af
 
-from audinterface.core.typing import (
-    Timestamp,
-    Timestamps,
-)
+from audinterface.core.typing import Timestamp
+from audinterface.core.typing import Timestamps
 
 
 def assert_index(obj: pd.Index):
     r"""Check if index is conform to audformat."""
-
     if isinstance(obj, pd.MultiIndex) and len(obj.levels) == 2:
 
         if obj.has_duplicates:
@@ -64,7 +61,7 @@ def assert_index(obj: pd.Index):
 
 
 def is_scalar(value: typing.Any) -> bool:
-    r"""Check if value is scalar"""
+    r"""Check if value is scalar."""
     return (value is not None) and \
            (isinstance(value, str) or not hasattr(value, '__len__'))
 
@@ -78,7 +75,6 @@ def preprocess_signal(
         mixdown: bool,
 ) -> (np.ndarray, int):
     r"""Pre-process signal."""
-
     signal = np.atleast_2d(signal)
 
     if channels is not None or mixdown:
@@ -166,9 +162,9 @@ def segment_to_indices(
     if pd.isna(end):
         end = pd.to_timedelta(signal.shape[-1] / sampling_rate, unit='s')
     max_i = signal.shape[-1]
-    start_i = int(round(start.total_seconds() * sampling_rate))
+    start_i = audmath.samples(start.total_seconds(), sampling_rate)
     start_i = min(start_i, max_i)
-    end_i = int(round(end.total_seconds() * sampling_rate))
+    end_i = audmath.samples(end.total_seconds(), sampling_rate)
     end_i = min(end_i, max_i)
     return start_i, end_i
 
