@@ -1,15 +1,21 @@
 import os
 
-import audiofile
-import audiofile as af
 import numpy as np
 import pandas as pd
 import pytest
 
-import audinterface
+import audeer
 import audformat
+import audiofile
+import audiofile as af
 import audobject
 
+import audinterface
+
+
+def identity(signal, sampling_rate):
+    return signal
+
 
 def signal_duration(signal, sampling_rate):
     return signal.shape[1] / sampling_rate
@@ -300,6 +306,28 @@ def signal_modification(signal, sampling_rate, subtract=False):
             False,
             1.0,
         ),
+        # Test for certain `start`, `end` values
+        # that were failing before
+        # https://github.com/audeering/audinterface/issues/123
+        (
+            identity,
+            None,
+            np.concatenate(
+                [
+                    np.zeros((1, 18240)),
+                    np.ones((1, 6720)),
+                    np.zeros((1, 23040)),
+                ],
+                axis=1,
+            ),
+            16000,
+            pd.Timedelta('0 days 00:00:01.140000'),
+            pd.Timedelta('0 days 00:00:01.560000'),
+            True,
+            None,
+            False,
+            np.ones((1, 6720), 'float32'),
+        ),
     ],
 )
 def test_process_file(
@@ -338,8 +366,9 @@ def test_process_file(
         start=start,
         end=end,
     )
+
     np.testing.assert_almost_equal(
-        y.values, expected_output, decimal=4,
+        y.values[0], expected_output, decimal=4,
     )
 
     # test relative path
@@ -349,8 +378,9 @@ def test_process_file(
         end=end,
         root=root,
     )
+
     np.testing.assert_almost_equal(
-        y.values, expected_output, decimal=4,
+        y.values[0], expected_output, decimal=4,
     )
 
 
@@ -561,7 +591,8 @@ def test_process_index(tmpdir, num_workers, multiprocessing, preserve_index):
         verbose=False,
     )
     sampling_rate = 8000
-    signal = np.random.uniform(-1.0, 1.0, (1, 3 * sampling_rate))
+    duration = 3.5225
+    signal = np.random.uniform(-1.0, 1.0, (1, int(duration * sampling_rate)))
 
     # create file
     root = str(tmpdir.mkdir('wav'))
@@ -623,6 +654,13 @@ def test_process_index(tmpdir, num_workers, multiprocessing, preserve_index):
             signal, sampling_rate = audinterface.utils.read_audio(path)
             np.testing.assert_equal(signal, value)
     else:
+        durations = [audiofile.duration(file) for file in index]
+        expected_index = audformat.segmented_index(
+            files=list(index),
+            starts=[0] * len(index),
+            ends=durations,
+        )
+        pd.testing.assert_index_equal(y.index, expected_index)
         for (path, start, end), value in y.items():
             signal, sampling_rate = audinterface.utils.read_audio(
                 path, start=start, end=end
@@ -677,6 +715,34 @@ def test_process_index(tmpdir, num_workers, multiprocessing, preserve_index):
     pd.testing.assert_series_equal(y, y_cached)
 
 
+def test_process_index_filewise_end_times(tmpdir):
+
+    # Ensure the resulting segmented index
+    # returned by audinterface.process_index()
+    # and by audformat.Table.get()
+    # have identical end times
+    # if NaT is forbidden,
+    # see https://github.com/audeering/audinterface/issues/113
+
+    db_root = audeer.mkdir(audeer.path(tmpdir, 'tmp'))
+    sampling_rate = 8000
+    duration = 2.5225
+    signal = np.ones((1, int(duration * sampling_rate)))
+    audiofile.write(audeer.path(db_root, 'f.wav'), signal, sampling_rate)
+    db = audformat.Database('db')
+    index = audformat.filewise_index(['f.wav'])
+    db['table'] = audformat.Table(index)
+    db['table']['column'] = audformat.Column()
+    db['table']['column'].set(['label'])
+    db.save(db_root)
+
+    df = db['table'].get(as_segmented=True, allow_nat=False)
+    expected_index = df.index
+    interface = audinterface.Process(process_func=lambda x, fs: x.max())
+    df = interface.process_index(db['table'].index, root=db_root)
+    pd.testing.assert_index_equal(df.index, expected_index)
+
+
 @pytest.mark.parametrize(
     'process_func, process_func_args, segment, signal, '
     'sampling_rate, file, start, end, keep_nat, expected_signal',
@@ -1442,7 +1508,7 @@ def test_process_with_special_args(tmpdir):
     )
     pd.testing.assert_series_equal(y, expected)
 
-    # explicitely pass special arguments
+    # explicitly pass special arguments
 
     process = audinterface.Process(
         process_func=process_func,
